package com.sdk.samples.fragment;

import org.json.JSONObject;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Bitmap;
import android.os.Handler;
import android.util.Log;
import com.uzmap.pkg.openapi.APIListener;
import com.uzmap.pkg.openapi.SuperWebview;
import com.uzmap.pkg.openapi.WebViewProvider;
import com.uzmap.pkg.uzcore.uzmodule.UZModuleContext;

public class MyAPIListener extends APIListener{

	private SuperWebview mSuperWebview;
	
	public MyAPIListener(SuperWebview superWebview){
		mSuperWebview = superWebview;
	}
	
	/**
	 * 重写该函数，可实现处理收到来自Html5页面的操作请求，处理完毕后异步回调至Html5
	 */
	@Override
	protected boolean onHtml5AccessRequest(WebViewProvider provider, UZModuleContext moduleContext) {
		String name = moduleContext.optString("name");
		//"requestEvent"与assets/widget/html/wind.html页面的发送请求相匹配
		if("requestEvent".equals(name)){
			JSONObject extra = new JSONObject();
			try{
				extra.put("value", "哈哈哈，我是来自Native的事件");
			}catch(Exception e){
				;
			}
			//"fromNative"与assets/widget/html/wind.html页面的apiready中注册的监听相对应
			mSuperWebview.sendEventToHtml5("fromNative", extra);
			return true;
		}
		defaultHandleHtml5AccessRequest(moduleContext);
		return true;
	}

	/**
	 * 重写该函数，可实现处理某Html5页面开始加载时，执行相应的逻辑
	 */
	@Override
	protected void onPageStarted(WebViewProvider provider, String url, Bitmap favicon) {
		//远程Url，加载较慢
		if(url.startsWith("http")){
			showProgress();
		}
	}

	/**
	 * 重写该函数，可实现处理某Html5页面结束加载时，执行相应的逻辑
	 */
	@Override
	protected void onPageFinished(WebViewProvider provider, String url) {
		//远程Url，加载较慢
		if(url.startsWith("http")){
			printMsg("加载进度：100");
			hidenProgress();
		};
	}

	/**
	 * 重写该函数，可实现处理某Html5页面加载进度发生变化时，执行相应的逻辑
	 */
	@Override
	protected void onProgressChanged(WebViewProvider provider, int newProgress) {
		//远程Url，加载较慢，显示进度，提升体验
		printMsg("加载进度：" + newProgress);
		if(100 == newProgress){
			hidenProgress();
		}
	}

	/**
	 * 重写该函数，可实现处理某Html5页面dom的title标签发生变化时，执行相应的逻辑
	 */
	@Override
	protected void onReceivedTitle(WebViewProvider provider, String title) {
		;
	}

	/**
	 * 重写该函数，可实现处理拦截某Html5页面是否允许访问某API，如模块的API，APICloud引擎的API
	 */
	@Override
	protected boolean shouldForbiddenAccess(String host, String module, String api) {
		
		return false;
	}

	/**
	 * 重写该函数，可实现处理当某Webview即将加载某Url时，是否进行拦截，拦截后，该Webview将不继续加载该Url
	 */
	@Override
	protected boolean shouldOverrideUrlLoading(WebViewProvider provider, String url) {
		if(url.contains("taobao")){
			showAlert("不允许访问淘宝！");
			return true;
		}
		return false;
	}
	
	//默认处理收到收到来自Html5页面的操作请求，并通过UZModuleContext给予JS回调
	private void defaultHandleHtml5AccessRequest(final UZModuleContext moduleContext){
		String name = moduleContext.optString("name");
		Object extra = moduleContext.optObject("extra");
		AlertDialog.Builder dia = new AlertDialog.Builder(mSuperWebview.getContext(), AlertDialog.THEME_HOLO_LIGHT);
		dia.setTitle("提示消息");
		dia.setMessage("收到来自Html5页面的操作请求，访问的名称标识为：\n[" + name + "]\n传入的参数为：\n[" + extra + "]\n\n" + "是否处理？\n");
		dia.setCancelable(false);
		dia.setPositiveButton("不处理", null);
		dia.setNegativeButton("处理", new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				dialog.dismiss();
				JSONObject json = new JSONObject();
				try{
					json.put("result0", "value0");
					json.put("result1", "value1");
					json.put("result2", "value2");
				}catch(Exception e){
					;
				}
				moduleContext.success(json, true);
			}
		});
		dia.show();
	}
	
	private void showAlert(String message){
		AlertDialog.Builder dia = new AlertDialog.Builder(mSuperWebview.getContext(), AlertDialog.THEME_HOLO_LIGHT);
		dia.setTitle("提示消息");
		dia.setMessage(message);
		dia.setCancelable(false);
		dia.setPositiveButton("确定", new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				;
			}
		});
		dia.show();
	}
	
	private void showProgress(){
		printMsg("加载开始");
	}
	
	private void hidenProgress(){
		new Handler().postDelayed(new Runnable() {
			
			@Override
			public void run() {
				printMsg("加载结束");
			}
		}, 1500);
	}
	
	static void printMsg(String msg){
		Log.d("apicloud", "" + msg);
	}
}
